Getting started
===============

To run PyEDB-Core, you must have a licensed copy of AEDT installed.

PyEDB-Core has two installation modes: user and developer. The following instructions
assume that you want to install PyEDB-Core in user mode. If you want to contribute to the
development of PyEDB-Core, you must install it in developer mode. For more information, see
:ref:`contribute_pyedb`.

Installation
------------

#. To ensure that you have the latest version of `pip`_, run this command:

   .. code:: bash

       python -m pip install -U pip

#. To install PyEDB-Core, run this command:

   .. code:: bash

       python -m pip install ansys-edb-core

.. LINKS AND REFERENCES
.. _pip: https://pypi.org/project/pip/